==> asaaspy-0.1.0.tar.gz: asaaspy-0.1.0/tests/customer/test_asaas_customer.py <==
import pytest
from asaaspy.service import AsaasService
from asaaspy.schemas.customer import CustomerSchema, CustomerCreateSchema
from tests.factories.customer import CustomerCreateSchemaFactory


class TestAsaasGetCustomer:
    def test_get_all_customers(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc
        all_customers = asaas_svc.customer.all()

        assert all_customers.totalCount == 3
        assert isinstance(all_customers.data[0], CustomerSchema)

    @pytest.mark.parametrize('extra_params', (
            {"name": "Pedro"},
            {"name": "Lucas", "email": "joaodascouves1@gmail.com"}
    ))
    def test_get_all_customers_with_filter(self, asaas_svc, extra_params):
        asaas_svc: AsaasService = asaas_svc
        
        all_customers = asaas_svc.customer.all()

        assert all_customers.hasMore is False


class TestAsaasCreateCustomer:
    def test_create_customer(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc
        
        customer = CustomerCreateSchema(name="Karen Baldwin", cpfCnpj="458.907.623-38") 
        new_customer = asaas_svc.customer.create(customer)

        assert new_customer.id is not None


class TestAsaasDeleteCustomer:
    def test_delete(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc

        customer = CustomerCreateSchema(name="Usuario a Ser Excluido", cpfCnpj="083.138.660-63") 
        new_customer = asaas_svc.customer.create(customer)

        has_deleted = asaas_svc.customer.delete(id=new_customer.id)

        assert has_deleted

==> asaaspy-0.4.1.tar.gz: asaaspy-0.4.1/tests/customer/test_asaas_customer.py <==
import pytest

from asaaspy.schemas.customer import CustomerCreateSchema, CustomerViewSchema
from asaaspy.service import AsaasService


class TestAsaasGetCustomer:
    def test_get_all_customers(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc
        all_customers = asaas_svc.customer.all()

        assert all_customers.totalCount == 3
        assert isinstance(all_customers.data[0], CustomerViewSchema)

    def test_get_customer(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc

        CUSTOMER_ID = "cus_000006102042"
        customer = asaas_svc.customer.get(customer_id=CUSTOMER_ID)

        assert customer.id == CUSTOMER_ID

    @pytest.mark.parametrize(
        "extra_params",
        ({"name": "Pedro"}, {"name": "Lucas", "email": "joaodascouves1@gmail.com"}),
    )
    def test_get_all_customers_with_filter(self, asaas_svc, extra_params):
        asaas_svc: AsaasService = asaas_svc

        all_customers = asaas_svc.customer.all()

        assert all_customers.hasMore is False


class TestAsaasCreateCustomer:
    def test_create_customer(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc

        customer = CustomerCreateSchema(name="Karen Baldwin", cpfCnpj="458.907.623-38")
        new_customer = asaas_svc.customer.create(customer)

        assert new_customer.id is not None

    def test_create_customer_minimal(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc

        customer = CustomerCreateSchema(name="Empresa Apenas com o nome")
        new_customer = asaas_svc.customer.create(customer)

        assert new_customer.id.startswith("cus_")


class TestAsaasDeleteCustomer:
    def test_delete(self, asaas_svc):
        asaas_svc: AsaasService = asaas_svc

        customer = CustomerCreateSchema(
            name="Usuario a Ser Excluido", cpfCnpj="083.138.660-63"
        )
        new_customer = asaas_svc.customer.create(customer)

        has_deleted = asaas_svc.customer.delete(id=new_customer.id)

        assert has_deleted
